Module beamlit.api.workspaces
=============================

Sub-modules
-----------
* beamlit.api.workspaces.accept_workspace_invitation
* beamlit.api.workspaces.create_worspace
* beamlit.api.workspaces.decline_workspace_invitation
* beamlit.api.workspaces.delete_workspace
* beamlit.api.workspaces.get_workspace
* beamlit.api.workspaces.invite_workspace_user
* beamlit.api.workspaces.leave_workspace
* beamlit.api.workspaces.list_workspace_users
* beamlit.api.workspaces.list_workspaces
* beamlit.api.workspaces.remove_workspace_user
* beamlit.api.workspaces.update_workspace
* beamlit.api.workspaces.update_workspace_user_role